@@ -30,7 +30,6 @@
 #include "mprocess.h"
 #include "msettings.h"
 #include "partman.h"
-#include "blockdev.h"
 #include "safecache.h"
 
 #include "ui_meinstall.h"
@@ -148,7 +147,6 @@ private:
 
     QWidget *nextFocus = nullptr;
     PartMan partman;
-    BlockDeviceList listBlkDevs;
     QStringList listHomes;
     SafeCache key;
 
@@ -172,7 +170,6 @@ private:
     // private functions
     void updateCursor(const Qt::CursorShape shape = Qt::ArrowCursor);
     void updatePartitionWidgets(bool all);
-    void updatePartitionCombos(QComboBox *changed);
     void setupPartitionSlider();
     void setupAutoMount(bool enabled);
     bool pretendToInstall(int space, long steps);
