@@ -1,19 +1,22 @@
-// MProcess class - Installer-specific extensions to QProcess.
-//
-//   Copyright (C) 2019 by AK-47
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-//
-// This file is part of the gazelle-installer.
+/***************************************************************************
+ * MProcess class - Installer-specific extensions to QProcess.
+ ***************************************************************************
+ *
+ *   Copyright (C) 2019 by AK-47
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ * This file is part of the gazelle-installer.
+ ***************************************************************************/
 
 #include <QApplication>
 #include <QDebug>
@@ -42,12 +45,16 @@ bool MProcess::exec(const QString &cmd, const bool rawexec, const QByteArray *in
 {
     if (halting) return false;
     ++execount;
-    qDebug().nospace() << "Exec #" << execount << ": " << cmd;
+    qDebug().nospace().noquote() << "Exec #" << execount << ": " << cmd;
     QListWidgetItem *logEntry = log(cmd, Exec);
     QEventLoop eloop;
     connect(this, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), &eloop, &QEventLoop::quit);
-    if (rawexec) start(cmd);
-    else start("/bin/bash", {"-c", cmd});
+    if (!rawexec) start("/bin/bash", {"-c", cmd});
+    else {
+        QStringList args = splitCommand(cmd);
+        QString prog = args.takeFirst();
+        start(prog, args);
+    }
     if (!debugUnusedOutput) {
         if (!needRead) closeReadChannel(QProcess::StandardOutput);
         closeReadChannel(QProcess::StandardError);
@@ -95,7 +102,7 @@ QString MProcess::execOut(const QString &cmd, bool everything)
 QStringList MProcess::execOutLines(const QString &cmd, const bool rawexec)
 {
     exec(cmd, rawexec, nullptr, true);
-    return QString(readAllStandardOutput().trimmed()).split('\n', QString::SkipEmptyParts);
+    return QString(readAllStandardOutput().trimmed()).split('\n', Qt::SkipEmptyParts);
 }
 
 void MProcess::halt()
@@ -119,6 +126,24 @@ void MProcess::unhalt()
     halting = false;
 }
 
+QString MProcess::joinCommand(const QString &program, const QStringList &arguments)
+{
+    QString text = program;
+    for(QString arg : arguments) {
+        bool wspace = false;
+        for(const auto &ch : arg) {
+            if (ch.isSpace()) {
+                wspace = true;
+                break;
+            }
+        }
+        arg.replace("\"", "\\\"");
+        if (!wspace) text += ' ' + arg;
+        else text += " \"" + arg + "\"";
+    }
+    return text;
+}
+
 QListWidgetItem *MProcess::log(const QString &text, const LogType type)
 {
     if (type == Standard) qDebug().noquote() << text;
@@ -164,7 +189,7 @@ void MProcess::status(long progress)
     int slice = progSliceSpace;
     if (progSliceSteps > 0) {
         if (progSlicePos > progSliceSteps) progSlicePos = progSliceSteps;
-        slice = (progSlicePos * progSliceSpace) / progSliceSteps;
+        slice = static_cast<int>((progSlicePos * progSliceSpace) / progSliceSteps);
     }
     if (progBar) progBar->setValue(progSliceStart + slice);
     qApp->processEvents();
@@ -198,14 +223,14 @@ void MProcess::sleep(const int msec, const bool silent)
     const int rc = eloop.exec();
     if (!silent) {
         qDebug().nospace() << "Sleep #" << sleepcount << ": exit " << rc;
-        log(logEntry, rc==0?1:-1);
+        log(logEntry, rc == 0 ? 1 : -1);
     }
 }
 bool MProcess::mkpath(const QString &path)
 {
     QListWidgetItem *logEntry = log("MKPATH: "+path, Exec);
     const bool rc = QDir().mkpath(path);
-    qDebug() << (rc?"MkPath(SUCCESS):":"MkPath(FAILURE):") << path;
-    log(logEntry, rc?1:-1);
+    qDebug() << (rc ? "MkPath(SUCCESS):" : "MkPath(FAILURE):") << path;
+    log(logEntry, rc ? 1 : -1);
     return rc;
 }
