@@ -124,7 +124,9 @@ void PartMan::scan(DeviceItem *drvstart)
         drvit->flags.curEmpty = true;
         drvit->flags.oldLayout = true;
         drvit->device = jdName;
-        drvit->flags.useGPT = (jsonDrive["pttype"]=="gpt");
+        const QString &ptType = jsonDrive["pttype"].toString();
+        drvit->flags.curGPT = (ptType=="gpt");
+        drvit->flags.curMBR = (ptType=="dos");
         drvit->size = jsonDrive["size"].toVariant().toLongLong();
         drvit->physec = jsonDrive["phy-sec"].toInt();
         drvit->curLabel = jsonDrive["label"].toString();
@@ -132,7 +134,8 @@ void PartMan::scan(DeviceItem *drvstart)
         const QJsonArray &jsonParts = jsonDrive["children"].toArray();
         for (const QJsonValue &jsonPart : jsonParts) {
             const QString &partTypeName = jsonPart["parttypename"].toString();
-            if (partTypeName=="Extended") continue;
+            if (partTypeName == "Extended" || partTypeName == "W95 Ext'd (LBA)"
+                || partTypeName == "Linux extended") continue;
             DeviceItem *partit = new DeviceItem(DeviceItem::Partition, drvit);
             drvit->flags.curEmpty = false;
             partit->flags.oldLayout = true;
@@ -145,8 +148,8 @@ void PartMan::scan(DeviceItem *drvstart)
             const int partflags = jsonPart["partflags"].toString().toUInt(nullptr, 0);
             if ((partflags & 0x80) || (partflags & 0x04)) partit->setActive(true);
             partit->mapCount = jsonPart["children"].toArray().count();
-            partit->flags.curESP = (partTypeName=="EFI System");
-            if (!partit->flags.nasty) partit->flags.nasty = partTypeName.startsWith("Microsoft LDM");
+            partit->flags.curESP = partTypeName.startsWith("EFI "); // "System"/"(FAT-12/16/32)"
+            if (partTypeName.startsWith("Microsoft LDM")) partit->flags.nasty = true;
             partit->flags.bootRoot = (!bootUUID.isEmpty() && jsonPart["uuid"]==bootUUID);
             partit->curFormat = jsonPart["fstype"].toString();
             // Propagate the boot and nasty flags up to the drive.
@@ -163,6 +166,10 @@ void PartMan::scan(DeviceItem *drvstart)
         }
         drvit->sortChildren();
         notifyChange(drvit);
+        // Hide the live boot media and its partitions by default.
+        if (!brave && drvit->flags.bootRoot) {
+            gui.treePartitions->setRowHidden(drvit->row(), QModelIndex(), true);
+        }
     }
 
     if (!drvstart) scanVirtualDevices(false);
@@ -213,7 +220,7 @@ void PartMan::scanVirtualDevices(bool rescan)
         DeviceItem *devit = listed.value(name);
         if (devit) {
             if (size != devit->size || physec != devit->physec || label != devit->curLabel
-                || crypto != devit->flags.cryptoV) {
+                || crypto != devit->flags.volCrypto) {
                 // List entry is different to the device, so refresh it.
                 delete devit;
                 devit = nullptr;
@@ -229,7 +236,7 @@ void PartMan::scanVirtualDevices(bool rescan)
             devit->flags.bootRoot = (!bootUUID.isEmpty() && jsonDev["uuid"]==bootUUID);
             devit->curLabel = label;
             devit->curFormat = jsonDev["fstype"].toString();
-            devit->flags.cryptoV = crypto;
+            devit->flags.volCrypto = crypto;
             devit->flags.oldLayout = true;
         }
     }
@@ -280,10 +287,11 @@ bool PartMan::manageConfig(MSettings &config, bool save)
             config.beginGroup(groupPart);
             if (save) {
                 config.setValue("Size", partit->size);
-                config.setValue("Encrypt", partit->encrypt);
-                if (partit->isActive()) config.setValue("Boot", true);
+                if (partit->isActive()) config.setValue("Active", true);
+                if (partit->addToCrypttab) config.setValue("AddToCrypttab", true);
                 if (!partit->usefor.isEmpty()) config.setValue("UseFor", partit->usefor);
                 if (!partit->format.isEmpty()) config.setValue("Format", partit->format);
+                config.setValue("Encrypt", partit->encrypt);
                 if (!partit->label.isEmpty()) config.setValue("Label", partit->label);
                 if (!partit->options.isEmpty()) config.setValue("Options", partit->options);
                 config.setValue("CheckBadBlocks", partit->chkbadblk);
@@ -294,8 +302,9 @@ bool PartMan::manageConfig(MSettings &config, bool save)
                     partit->size = config.value("Size").toLongLong();
                     sizeTotal += partit->size;
                     if (sizeTotal > sizeMax) return false;
-                    if (config.value("Boot").toBool()) partit->setActive(true);
+                    if (config.value("Active").toBool()) partit->setActive(true);
                 }
+                partit->addToCrypttab = config.value("AddToCrypttab").toBool();
                 partit->usefor = config.value("UseFor", partit->usefor).toString();
                 partit->format = config.value("Format", partit->format).toString();
                 partit->chkbadblk = config.value("CheckBadBlocks", partit->chkbadblk).toBool();
@@ -412,12 +421,12 @@ void PartMan::treeMenu(const QPoint &)
         QAction *actUnlock = nullptr;
         QAction *actAddCrypttab = nullptr;
         QAction *actNewSubvolume = nullptr, *actScanSubvols = nullptr;
-        QAction *actSetBoot = nullptr;
+        QAction *actActive = nullptr;
         actRemove->setEnabled(gui.pushPartRemove->isEnabled());
         menu.addSeparator();
         if (twit->type == DeviceItem::VirtualBD) {
             actRemove->setEnabled(false);
-            if (twit->flags.cryptoV) actLock = menu.addAction(tr("&Lock"));
+            if (twit->flags.volCrypto) actLock = menu.addAction(tr("&Lock"));
         } else {
             bool allowCryptTab = false;
             if (twit->flags.oldLayout && twit->curFormat == "crypto_LUKS") {
@@ -428,13 +437,13 @@ void PartMan::treeMenu(const QPoint &)
             if (allowCryptTab) {
                 actAddCrypttab = menu.addAction(tr("Add to crypttab"));
                 actAddCrypttab->setCheckable(true);
-                actAddCrypttab->setChecked(twit->flags.autoCrypto);
+                actAddCrypttab->setChecked(twit->addToCrypttab);
                 actAddCrypttab->setEnabled(twit->willMap());
             }
             menu.addSeparator();
-            actSetBoot = menu.addAction(tr("Set boot flag"));
-            actSetBoot->setCheckable(true);
-            actSetBoot->setChecked(twit->isActive());
+            actActive = menu.addAction(tr("Active partition"));
+            actActive->setCheckable(true);
+            actActive->setChecked(twit->isActive());
         }
         if (twit->format == "btrfs") {
             menu.addSeparator();
@@ -449,10 +458,9 @@ void PartMan::treeMenu(const QPoint &)
         else if (action == actRemove) partRemoveClick(true);
         else if (action == actUnlock) partMenuUnlock(twit);
         else if (action == actLock) partMenuLock(twit);
-        else if (action == actSetBoot) twit->setActive(action->isChecked());
-        else if (action == actAddCrypttab) {
-            twit->flags.autoCrypto = action->isChecked();
-        } else if (action == actNewSubvolume) {
+        else if (action == actActive) twit->setActive(action->isChecked());
+        else if (action == actAddCrypttab) twit->addToCrypttab = action->isChecked();
+        else if (action == actNewSubvolume) {
             new DeviceItem(DeviceItem::Subvolume, twit);
             gui.treePartitions->expand(selIndex);
         } else if (action == actScanSubvols) {
@@ -556,7 +564,7 @@ void PartMan::partMenuUnlock(DeviceItem *twit)
         const bool ok = luksOpen(twit->device, mapdev, editPass->text().toUtf8());
         if (ok) {
             twit->usefor.clear();
-            twit->flags.autoCrypto = checkCrypttab->isChecked();
+            twit->addToCrypttab = checkCrypttab->isChecked();
             twit->mapCount++;
             notifyChange(twit);
             scanVirtualDevices(true);
@@ -584,7 +592,7 @@ void PartMan::partMenuLock(DeviceItem *twit)
     if (ok) {
         if (origin->mapCount > 0) origin->mapCount--;
         origin->devMapper.clear();
-        origin->flags.autoCrypto = false;
+        origin->addToCrypttab = false;
         notifyChange(origin);
     }
     // Refresh virtual devices list.
@@ -716,10 +724,8 @@ bool PartMan::composeValidate(bool automatic, const QString &project)
         for (int ixdrv = 0; ixdrv < root.childCount(); ++ixdrv) {
             DeviceItem *drvit = root.child(ixdrv);
             const int partCount = drvit->childCount();
-            bool setupGPT = uefi || gptoverride || drvit->size >= 2199023255552 || partCount > 4;
-            if (drvit->flags.oldLayout) {
-                setupGPT = drvit->flags.useGPT;
-            } else if (drvit->type != DeviceItem::VirtualDevices) {
+            bool setupGPT = drvit->willUseGPT();
+            if (!drvit->flags.oldLayout && drvit->type != DeviceItem::VirtualDevices) {
                 details += tr("Prepare %1 partition table on %2").arg(setupGPT?"GPT":"MBR", drvit->device) + '\n';
             }
             bool hasBiosGrub = false;
@@ -876,9 +882,11 @@ int PartMan::countPrepSteps()
             else if (!tuse.isEmpty()) ++nstep; // Existing partition
             // Formatting
             if (item->encrypt) nstep += 2; // LUKS Format
-            if (item->willFormat()) ++nstep; // New file system or subvolume
+            if (item->willFormat()) ++nstep; // New file system
             // Mounting
             if (tuse.startsWith('/')) ++nstep;
+        } else if (item->type == DeviceItem::Subvolume) {
+            ++nstep; // Create a new subvolume.
         }
     }
     return nstep;
@@ -903,8 +911,6 @@ bool PartMan::preparePartitions()
         } else {
             // Clearing the drive, so mark all partitions on the drive for unmounting.
             listToUnmount << proc.execOutLines("lsblk -nro name /dev/" + drvit->device, true);
-            // See if GPT needs to be used (either UEFI or >=2TB drive)
-            drvit->flags.useGPT = (gptoverride || uefi || drvit->size >= 2199023255552 || partCount > 4);
         }
     }
     for (const QString &strdev : listToUnmount) {
@@ -927,7 +933,7 @@ bool PartMan::preparePartitions()
         // Last 17KB = secondary partition table (for GPT disks).
         proc.exec(cmd + " seek=" + QString::number(offset));
         if (!proc.exec("parted -s /dev/" + drvit->device + " mklabel "
-            + (drvit->flags.useGPT ? "gpt" : "msdos"))) return false;
+            + (drvit->willUseGPT() ? "gpt" : "msdos"))) return false;
     }
 
     // Prepare partition tables, creating tables and partitions when needed.
@@ -936,7 +942,7 @@ bool PartMan::preparePartitions()
         DeviceItem *drvit = root.child(ixi);
         if (drvit->type == DeviceItem::VirtualDevices) continue;
         const int devCount = drvit->childCount();
-        const bool useGPT = drvit->flags.useGPT;
+        const bool useGPT = drvit->willUseGPT();
         if (drvit->flags.oldLayout) {
             // Using existing partitions.
             QString cmd; // command to set the partition type
@@ -1128,7 +1134,7 @@ bool PartMan::fixCryptoSetup(const QString &keyfile, bool isNewKey)
     // Find extra devices
     QMap<QString, QString> extraAdd;
     for (DeviceItemIterator it(*this); DeviceItem *item = *it; it.next()) {
-        if (item->flags.autoCrypto) extraAdd.insert(item->device, item->mappedDevice());
+        if (item->addToCrypttab) extraAdd.insert(item->device, item->mappedDevice());
     }
     // File systems
     for (auto &it : mounts.toStdMap()) {
@@ -1363,6 +1369,7 @@ QVariant PartMan::data(const QModelIndex &index, int role) const
         switch (index.column()) {
         case Device:
             if (item->type == DeviceItem::Subvolume) return "----";
+            else if (item->isActive()) return item->device + '*';
             else return item->device;
             break;
         case Size:
@@ -1378,8 +1385,13 @@ QVariant PartMan::data(const QModelIndex &index, int role) const
             else return item->curLabel;
             break;
         case Format:
-            if (item->usefor.isEmpty()) return item->curFormat;
-            else return item->shownFormat(item->format);
+            if (item->type == DeviceItem::Drive) {
+                if (item->willUseGPT()) return "GPT";
+                else if (item->flags.curMBR || !item->flags.oldLayout) return "MBR";
+            } else {
+                if (item->usefor.isEmpty()) return item->curFormat;
+                else return item->shownFormat(item->format);
+            }
             break;
         case Options:
             if (item->canMount() || item->realUseFor() == "SWAP") return item->options;
@@ -1407,15 +1419,11 @@ QVariant PartMan::data(const QModelIndex &index, int role) const
     } else if (role == Qt::DecorationRole && index.column() == Device) {
         if (item->type == DeviceItem::Drive && !item->flags.oldLayout) {
             return QIcon(":/appointment-soon");
-        } else if (item->type == DeviceItem::VirtualBD && item->flags.cryptoV) {
+        } else if (item->type == DeviceItem::VirtualBD && item->flags.volCrypto) {
             return QIcon::fromTheme("unlock");
         } else if (item->mapCount) {
             return QIcon::fromTheme("lock");
         }
-    } else if (role == Qt::FontRole && index.column() == Device) {
-        QFont font;
-        font.setItalic(item->isActive());
-        return font;
     }
     return QVariant();
 }
@@ -1449,13 +1457,12 @@ Qt::ItemFlags PartMan::flags(const QModelIndex &index) const
         }
         break;
     case UseFor:
-        if (item->allowedUsesFor().count() > 1) flagsOut |= Qt::ItemIsEditable;
+        if (item->allowedUsesFor().count() >= 1) flagsOut |= Qt::ItemIsEditable;
         break;
     case Label:
-        if (item->type == DeviceItem::Subvolume) {
-            if (item->format != "PRESERVE") flagsOut |= Qt::ItemIsEditable;
-        } else {
-            if (!item->usefor.isEmpty()) flagsOut |= Qt::ItemIsEditable;
+        if (item->format != "PRESERVE") {
+            if (item->type == DeviceItem::Subvolume) flagsOut |= Qt::ItemIsEditable;
+            else if (!item->usefor.isEmpty()) flagsOut |= Qt::ItemIsEditable;
         }
         break;
     case Encrypt:
@@ -1612,6 +1619,7 @@ DeviceItem::DeviceItem(enum DeviceType type, DeviceItem *parent, DeviceItem *pre
 {
     if (type == Partition) size = 1048576;
     if (parent) {
+        if (type == Subvolume) size = parent->size;
         physec = parent->physec;
         partman = parent->partman;
         const int i = preceding ? (parentItem->children.indexOf(preceding) + 1) : parentItem->childCount();
@@ -1728,6 +1736,14 @@ bool DeviceItem::isLocked() const
     }
     return (mapCount != 0);
 }
+inline bool DeviceItem::willUseGPT() const
+{
+    if (type != Drive) return false;
+    if (flags.oldLayout) return flags.curGPT;
+    else if (size >= 2199023255552 || children.count() > 4) return true;
+    else if (partman) return (partman->gptoverride || partman->uefi);
+    return false;
+}
 inline bool DeviceItem::willFormat() const
 {
     return format != "PRESERVE" && !usefor.isEmpty();
@@ -1764,7 +1780,7 @@ QString DeviceItem::shownDevice() const
 }
 QStringList DeviceItem::allowedUsesFor(bool real) const
 {
-    if (!isVolume()) return QStringList();
+    if (!isVolume() && type != Subvolume) return QStringList();
     QStringList list;
     if (!partman || size >= partman->rootSpaceNeeded) list << "root";
     if (type == Subvolume) list << "home"; // swap requires Linux 5.0 or later
@@ -1783,11 +1799,10 @@ QStringList DeviceItem::allowedUsesFor(bool real) const
 }
 QStringList DeviceItem::allowedFormats() const
 {
-    if (!isVolume()) return QStringList();
     QStringList list;
     bool allowPreserve = false, selPreserve = false;
     if (type == Subvolume) list.append("CREATE");
-    else {
+    else if (isVolume()) {
         const QString &use = realUseFor();
         if (use.isEmpty()) return QStringList();
         else if (use == "/boot") list.append("ext4");
@@ -1856,6 +1871,7 @@ DeviceItem *DeviceItem::addPart(int defaultMB, const QString &defaultUse, bool c
 void DeviceItem::driveAutoSetActive()
 {
     if (active) return;
+    if (partman && partman->uefi && willUseGPT()) return;
     const int partcount = children.count();
     for (const QString &pref : QStringList({"/boot", "/"})) {
         for (int ixPart = 0; ixPart < partcount; ++ixPart) {
