@@ -43,6 +43,7 @@ class DeviceItem
     QVector<DeviceItem *> children;
     DeviceItem *parentItem = nullptr;
     class PartMan *partman = nullptr;
+    int order = -1;
     DeviceItem *addPart(int defaultMB, const QString &defaultUse, bool crypto);
     void driveAutoSetActive();
     void autoFill(unsigned int changed = 0xFFFF);
@@ -59,24 +60,28 @@ public:
     } type;
     struct Flags {
         bool nasty : 1;
+        bool curEmpty : 1;
         bool oldLayout : 1;
-        bool start : 1;
-        bool useGPT : 1;
+        bool bootRoot : 1;
+        bool curMBR : 1;
+        bool curGPT : 1;
         bool curESP : 1;
-        bool cryptoV : 1;
-        bool autoCrypto : 1;
+        bool volCrypto : 1;
     } flags = {};
-    int mapCount = 0;
-    int physec;
     QString model, device, devMapper;
-    long long size = 0;
     QString label, curLabel;
     QString usefor;
-    bool encrypt = false;
     QString format, curFormat;
     QString options;
-    bool dump = false;
+    long long size = 0;
+    int mapCount = 0;
+    int physec;
     int pass = 0;
+    bool encrypt = false;
+    bool chkbadblk = false;
+    bool dump = false;
+    bool addToCrypttab = false;
+
     DeviceItem(enum DeviceType type, DeviceItem *parent = nullptr, DeviceItem *preceding = nullptr);
     ~DeviceItem();
     void clear();
@@ -93,6 +98,7 @@ public:
     void setActive(bool boot);
     bool isActive() const;
     bool isLocked() const;
+    bool willUseGPT() const;
     bool willFormat() const;
     bool canEncrypt() const;
     QString mappedDevice(const bool full = false) const;
@@ -103,6 +109,7 @@ public:
     QString shownFormat(const QString &fmt) const;
     inline bool isVolume() const { return (type == Partition || type == VirtualBD); }
     bool canMount() const;
+    long long driveFreeSpace(bool inclusive = false) const;
     /* Convenience */
     int layoutDefault(int rootPercent, bool crypto, bool updateTree=true);
     void addToCombo(QComboBox *combo, bool warnNasty = false) const;
@@ -130,7 +137,8 @@ class DeviceItemDelegate : public QStyledItemDelegate
         const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
     void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
-    void partOptionsMenu(const QPoint &);
+    void emitCommit();
+    void partOptionsMenu();
 };
 
 class PartMan : public QAbstractItemModel
@@ -144,12 +152,10 @@ class PartMan : public QAbstractItemModel
     Ui::MeInstall &gui;
     QWidget *master;
     QMap<QString, DeviceItem *> mounts;
-    QStringList listToUnmount;
     void setup();
     void scanVirtualDevices(bool rescan);
     void resizeColumnsToFit();
     bool formatLinuxPartition(const QString &devpath, const QString &format, bool chkBadBlocks, const QString &label);
-    bool calculatePartBD();
     bool prepareSubvolumes(DeviceItem *partit);
     DeviceItem *findOrigin(const QString &vdev);
     void treeItemChange();
@@ -173,11 +179,13 @@ public:
         Label,
         Encrypt,
         Format,
+        Check,
         Options,
         Dump,
         Pass,
         _TreeColumns_
     };
+    QString bootUUID;
     bool gptoverride=false, uefi=false, brave=false;
     long long rootSpaceNeeded = 0;
     long long bootSpaceNeeded = 0;
